@@ -3,12 +3,13 @@ OC.L10N.register(
     {
     "Details" : "Detallar",
     "Contacts" : "Əlaqələr",
-    "Send email" : "Email yolla",
-    "Download" : "Yüklə",
     "Rename" : "Adı dəyiş",
+    "Send email" : "Email yolla",
     "Delete" : "Sil",
+    "Download" : "Yüklə",
     "Copy link" : "linki nüsxələ",
     "can edit" : "dəyişmək olar",
+    "Add" : "Əlavə etmək",
     "Password protection" : "Password protection",
     "Save" : "Saxla",
     "Description" : "Açıqlanma",
@@ -27,7 +28,6 @@ OC.L10N.register(
     "Email" : "Email",
     "Admin" : "İnzibatçı",
     "Owner" : "Owner",
-    "Users" : "İstifadəçilər",
     "Prefix" : "Prefiks",
     "Suffix" : "Suffiks",
     "Nickname" : "Ləqəb",
