@@ -1,13 +1,21 @@
 OC.L10N.register(
     "contacts",
     {
-    "Loading" : "Loading",
-    "Title" : "Title",
-    "Delete" : "Delete",
-    "Cancel" : "Cancel",
     "Rename" : "Rename",
-    "Notes" : "Notes",
+    "Delete" : "Delete",
+    "Copy link" : "Скапіяваць спасылку",
+    "Add" : "Add",
+    "Password protection" : "Password protection",
+    "Save" : "Save",
+    "Settings" : "Settings",
+    "Cancel" : "Cancel",
+    "Title" : "Title",
+    "User" : "User",
+    "Group" : "Group",
     "Email" : "email",
+    "Owner" : "Owner",
+    "Notes" : "Notes",
+    "Home" : "Дадому",
     "Unknown" : "невядомы"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
