@@ -63,7 +63,6 @@ OC.L10N.register(
     "Renaming of address book was not successful." : "アドレス帳の名前変更に失敗しました。",
     "_%n contact_::_%n contacts_" : ["%n 連絡先"],
     "_%n group_::_%n groups_" : ["%n グループ"],
-    "_Shared with {num} entity_::_Shared with {num} entities_" : ["{num} 個のエンティティと共有"],
     "Share with users or groups" : "ユーザーまたはグループと共有する",
     "Share with users" : "ユーザーに共有",
     "No users or groups" : "ユーザーまたはグループはありません",
@@ -119,7 +118,6 @@ OC.L10N.register(
     "Crop contact photo" : "写真を切り抜き",
     "Upload a new picture" : "新しい写真をアップロードする",
     "Choose from Files" : "ファイルから選択",
-    "Get from " : "次から入手:",
     "Download picture" : "画像をダウンロード",
     "Delete picture" : "画像を削除",
     "Please select a valid format" : "有効なフォーマットを選択してください。",
@@ -209,11 +207,6 @@ OC.L10N.register(
     "Contact not found" : "連絡先がありません",
     "Group {group} not found" : "グループ {group} が見つかりません",
     "Close" : "閉じる",
-    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 件の連絡先を {name} に追加しました"],
-    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["{success} 件の連絡先を {name} に追加中"],
-    "_{count} error_::_{count} errors_" : ["{count} つのエラー"],
-    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["{アドレス帳}に %n の連絡先をインポートしています。"],
-    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["{アドレス帳}に %n 連絡先のインポートが完了しました"],
     "Import" : "インポート",
     "Are you sure you want to import this contact file?" : "この連絡先ファイルをインポートしますか?",
     "Could not copy" : "コピーできませんでした",
@@ -287,7 +280,6 @@ OC.L10N.register(
     "Voice" : "音声番号",
     "Car" : "自動車",
     "Work pager" : "ワークページャー",
-    "Manager" : "マネージャー",
     "Social network" : "ソーシャルネットワーク",
     "Relationship to you" : "あなたとの関係",
     "Spouse" : "配偶者",
@@ -315,6 +307,8 @@ OC.L10N.register(
     "An error has occurred in team(s). Check the console for more details." : "チームでエラーが発生しました。詳細については、コンソールを確認してください。",
     "Unable to create team {circleName}" : "チーム{circleName}を作成できません",
     "Unable to delete team {circleId}" : "チーム {circleId} を削除できません",
-    "Unable to delete contact" : "連絡先を削除できません。"
+    "Unable to delete contact" : "連絡先を削除できません。",
+    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "メンバーシップは、モデレーターにより確認/承認が必要です（開く要求）",
+    "Manager" : "マネージャー"
 },
 "nplurals=1; plural=0;");
